#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Enter the description of your new custom indicator here
    /// </summary>
    [Description("Enter the description of your new custom indicator here")]
    public class BelkhayateTrend : Indicator
    {
        #region Variables
        // Wizard generated variables
        private int period = 100; // Default setting for Period
        private int order = 3; // Default setting for Order
		private Color clrUp = Color.Lime;
		private Color clrDown = Color.Red;

		int day = -1;
		double [] pa;
		int [] dir;
		string alertCross = "alert1.wav";
		string alertFat = "alert1.wav";
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Green), PlotStyle.Line, "GC1"));
            Add(new Plot(Color.FromKnownColor(KnownColor.Green), PlotStyle.Dot, "Thick1"));
            Add(new Plot(Color.FromKnownColor(KnownColor.Green), PlotStyle.Dot, "Thick2"));
            Add(new Plot(Color.FromKnownColor(KnownColor.Green), PlotStyle.Dot, "Thick3"));
			
			Plots[1].Pen.Width = 2;
			Plots[2].Pen.Width = 3;
			Plots[3].Pen.Width = 4;
			
			if(Instrument != null)
			{
				if(BarsPeriod.Id == PeriodType.Minute)
				{
					if(BarsPeriod.Value < 5)
					{
						Add(PeriodType.Minute, 5);
						Add(PeriodType.Minute, 15);
						Add(PeriodType.Minute, 20);
						Add(PeriodType.Minute, 30);
						Add(PeriodType.Minute, 60);
						Add(PeriodType.Minute, 240);
						Add(PeriodType.Day, 1);
						day = 7;
						alertCross = "Daily line cross 1 to 3 min.wav";
						alertFat = "Fat line greater than 3 1m.wav";
					}
					else if(BarsPeriod.Value == 5)
					{
						Add(PeriodType.Minute, 15);
						Add(PeriodType.Minute, 20);
						Add(PeriodType.Minute, 30);
						Add(PeriodType.Minute, 60);
						Add(PeriodType.Minute, 120);
						Add(PeriodType.Minute, 240);
						Add(PeriodType.Day, 1);
						day = 7;
						alertCross = "Daily line cross 5 to 30 min.wav";
						alertFat = "Fat line greater than 3 5m.wav";
					}
					else if(BarsPeriod.Value > 5 && BarsPeriod.Value <= 15)
					{
						Add(PeriodType.Minute, 20);
						Add(PeriodType.Minute, 30);
						Add(PeriodType.Minute, 60);
						Add(PeriodType.Minute, 120);
						Add(PeriodType.Minute, 240);
						Add(PeriodType.Minute, 720);
						Add(PeriodType.Day, 1);
						day = 7;
						alertCross = "Daily line cross 5 to 30 min.wav";
						alertFat = "Fat line greater than 3 15m.wav";
					}
					else if(BarsPeriod.Value > 15 && BarsPeriod.Value <= 30)
					{
						Add(PeriodType.Minute, 60);
						Add(PeriodType.Minute, 120);
						Add(PeriodType.Minute, 240);
						Add(PeriodType.Minute, 720);
						Add(PeriodType.Day, 1);
						Add(PeriodType.Week, 1);
						day = 5;
						alertCross = "Daily line cross 5 to 30 min.wav";
						alertFat = "Fat line greater than 3 30m.wav";
					}
					else if(BarsPeriod.Value > 30 && BarsPeriod.Value <= 60)
					{
						Add(PeriodType.Minute, 120);
						Add(PeriodType.Minute, 240);
						Add(PeriodType.Minute, 720);
						Add(PeriodType.Day, 1);
						Add(PeriodType.Week, 1);
						Add(PeriodType.Month, 1);
						day = 4;
						alertCross = "Daily line cross higher.wav";
						alertFat = "Fat line greater than 3 60m.wav";
					}
				}
				else if(BarsPeriod.Id == PeriodType.Range)
				{
					if(BarsPeriod.Value <= 3)
					{
						Add(PeriodType.Range, 5);
						Add(PeriodType.Range, 8);
						Add(PeriodType.Range, 13);
						Add(PeriodType.Range, 21);
						Add(PeriodType.Minute, 60);
						Add(PeriodType.Minute, 240);
						Add(PeriodType.Day, 1);
						day = 7;
						alertCross = "Daily line cross 1 to 3 min.wav";
						alertFat = "Fat line greater than 3 1m.wav";
					}
					else if(BarsPeriod.Value <= 5)
					{
						Add(PeriodType.Range, 8);
						Add(PeriodType.Range, 13);
						Add(PeriodType.Range, 21);
						Add(PeriodType.Range, 34);
						Add(PeriodType.Day, 1);
						day = 5;
						alertCross = "Daily line cross 1 to 3 min.wav";
						alertFat = "Fat line greater than 3 1m.wav";
					}
					else if(BarsPeriod.Value <= 10)
					{
						Add(PeriodType.Range, 13);
						Add(PeriodType.Range, 21);
						Add(PeriodType.Range, 34);
						Add(PeriodType.Range, 55);
						Add(PeriodType.Day, 1);
						Add(PeriodType.Week, 1);
						day = 5;
						alertCross = "Daily line cross 1 to 3 min.wav";
						alertFat = "Fat line greater than 3 1m.wav";
					}
					else if(BarsPeriod.Value <= 15)
					{
						Add(PeriodType.Range, 21);
						Add(PeriodType.Range, 34);
						Add(PeriodType.Range, 55);
						Add(PeriodType.Day, 1);
						Add(PeriodType.Week, 1);
						day = 4;
						alertCross = "Daily line cross 1 to 3 min.wav";
						alertFat = "Fat line greater than 3 1m.wav";
					}
				}
			}
			
			pa = new double[8];
			dir = new int[8];
			for(int i = 0; i < 8; i++)
			{
				pa[i] = 0;
				dir[i] = 0;
			}
            Overlay				= true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if(CurrentBar < 10) return;
			
			double p1 = GravityCenter(0.618, Order, Period).GravityLine[0];
			double p2 = GravityCenter(0.618, Order, Period).GravityLine[1];
			
			if(BarsInProgress == 0)
			{
				GC1.Set(p1);
				if(GC1[0] > GC1[1])
				{
					PlotColors[BarsInProgress][0] = UpColor;
				}
				else if(GC1[0] < GC1[1])
				{
					PlotColors[BarsInProgress][0] = DownColor;
				}
			}

			pa[BarsInProgress] = p1;
			if(p1 > p2)
				dir[BarsInProgress] = 1;
			else if(p1 < p2)
				dir[BarsInProgress] = -1;
			
			int above = 0;
			int below = 0;
			for(int i = 1; i < 8; i++)
			{
				if(pa[i] > 0)
				{
					if(pa[0] > pa[i])
						above++;
					else if(pa[0] < pa[i])
						below++;
				}
			}
			if(GC1[0] > GC1[1] && above > 0)
			{
				if(below == 0)
				{
					Thick3.Set(GC1[0]);
					PlotColors[3][0] = UpColor;
				}
				if(above > below)
				{
					Thick2.Set(GC1[0]);
					PlotColors[2][0] = UpColor;
				}
				else
				{
					Thick1.Set(GC1[0]);
					PlotColors[1][0] = UpColor;
				}
			}
			else if(GC1[0] < GC1[1] && below > 0)
			{
				if(above == 0)
				{
					Thick3.Set(GC1[0]);
					PlotColors[3][0] = DownColor;
				}
				if(below > above)
				{
					Thick2.Set(GC1[0]);
					PlotColors[2][0] = DownColor;
				}
				else
				{
					Thick1.Set(GC1[0]);
					PlotColors[1][0] = DownColor;
				}
			}
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries GC1
        {
            get { return Values[0]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Thick1
        {
            get { return Values[1]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Thick2
        {
            get { return Values[2]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Thick3
        {
            get { return Values[3]; }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int Period
        {
            get { return period; }
            set { period = Math.Max(1, value); }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int Order
        {
            get { return order; }
            set { order = Math.Max(1, value); }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public Color UpColor
        {
            get { return clrUp; }
            set { clrUp = value; }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public Color DownColor
        {
            get { return clrDown; }
            set { clrDown = value; }
        }
		
		[Browsable(false)]
		public string UpColorSerialize
		{
     		get { return NinjaTrader.Gui.Design.SerializableColor.ToString(clrUp); }
     		set { clrUp = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
		}
		
		[Browsable(false)]
		public string DownColorSerialize
		{
     		get { return NinjaTrader.Gui.Design.SerializableColor.ToString(clrDown); }
     		set { clrDown = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
		}
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private BelkhayateTrend[] cacheBelkhayateTrend = null;

        private static BelkhayateTrend checkBelkhayateTrend = new BelkhayateTrend();

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public BelkhayateTrend BelkhayateTrend(Color downColor, int order, int period, Color upColor)
        {
            return BelkhayateTrend(Input, downColor, order, period, upColor);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public BelkhayateTrend BelkhayateTrend(Data.IDataSeries input, Color downColor, int order, int period, Color upColor)
        {
            if (cacheBelkhayateTrend != null)
                for (int idx = 0; idx < cacheBelkhayateTrend.Length; idx++)
                    if (cacheBelkhayateTrend[idx].DownColor == downColor && cacheBelkhayateTrend[idx].Order == order && cacheBelkhayateTrend[idx].Period == period && cacheBelkhayateTrend[idx].UpColor == upColor && cacheBelkhayateTrend[idx].EqualsInput(input))
                        return cacheBelkhayateTrend[idx];

            lock (checkBelkhayateTrend)
            {
                checkBelkhayateTrend.DownColor = downColor;
                downColor = checkBelkhayateTrend.DownColor;
                checkBelkhayateTrend.Order = order;
                order = checkBelkhayateTrend.Order;
                checkBelkhayateTrend.Period = period;
                period = checkBelkhayateTrend.Period;
                checkBelkhayateTrend.UpColor = upColor;
                upColor = checkBelkhayateTrend.UpColor;

                if (cacheBelkhayateTrend != null)
                    for (int idx = 0; idx < cacheBelkhayateTrend.Length; idx++)
                        if (cacheBelkhayateTrend[idx].DownColor == downColor && cacheBelkhayateTrend[idx].Order == order && cacheBelkhayateTrend[idx].Period == period && cacheBelkhayateTrend[idx].UpColor == upColor && cacheBelkhayateTrend[idx].EqualsInput(input))
                            return cacheBelkhayateTrend[idx];

                BelkhayateTrend indicator = new BelkhayateTrend();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.DownColor = downColor;
                indicator.Order = order;
                indicator.Period = period;
                indicator.UpColor = upColor;
                Indicators.Add(indicator);
                indicator.SetUp();

                BelkhayateTrend[] tmp = new BelkhayateTrend[cacheBelkhayateTrend == null ? 1 : cacheBelkhayateTrend.Length + 1];
                if (cacheBelkhayateTrend != null)
                    cacheBelkhayateTrend.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheBelkhayateTrend = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.BelkhayateTrend BelkhayateTrend(Color downColor, int order, int period, Color upColor)
        {
            return _indicator.BelkhayateTrend(Input, downColor, order, period, upColor);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.BelkhayateTrend BelkhayateTrend(Data.IDataSeries input, Color downColor, int order, int period, Color upColor)
        {
            return _indicator.BelkhayateTrend(input, downColor, order, period, upColor);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.BelkhayateTrend BelkhayateTrend(Color downColor, int order, int period, Color upColor)
        {
            return _indicator.BelkhayateTrend(Input, downColor, order, period, upColor);
        }

        /// <summary>
        /// Enter the description of your new custom indicator here
        /// </summary>
        /// <returns></returns>
        public Indicator.BelkhayateTrend BelkhayateTrend(Data.IDataSeries input, Color downColor, int order, int period, Color upColor)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.BelkhayateTrend(input, downColor, order, period, upColor);
        }
    }
}
#endregion
